pub unsafe fn execute_permute_blocked<T>(
src: *const T,
dst: *mut T,
plan: &PermutePlan,
)where
T: Copy,Expand description
Execute the permutation plan (single-threaded).
Safety
srcmust be valid for reads at all offsets determined by dims/src_stridesdstmust be valid for writes at all offsets determined by dims/dst_strides- src and dst must not overlap